==> xlr-domain-test-utils-24.3.5-sources.jar: com/xebialabs/xlrelease/TestIds.java <==
package com.xebialabs.xlrelease;

import static com.xebialabs.deployit.plugin.api.udm.Metadata.ConfigurationItemRoot.APPLICATIONS;
import static com.xebialabs.deployit.plugin.api.udm.Metadata.ConfigurationItemRoot.CONFIGURATION;

/**
 * Holds sets of ids to use in unit tests.
 * <p>
 * More and more business code depends on properly formed ids with coherent nesting. It's more convenient to define them once and for all here.
 * </p>
 */
public final class TestIds {
    private static final String ROOT = CONFIGURATION.getRootNodeName() + "/Users";
    public static final String RELEASES_DIR = APPLICATIONS.getRootNodeName();
    public static final String CONFIGURATIONS_CUSTOM_PREFIX = CONFIGURATION.getRootNodeName() + "/Custom";

    public static final String RELEASE1 = RELEASES_DIR + "/Release162151faba694d03aa3065665cf26f21";
    public static final String TEAM11 = RELEASE1 + "/Team175a73cb61dd42dfbaf6c0bf8190a99f";
    public static final String TEAM12 = RELEASE1 + "/Team96834368d2204b1e9dca9171e8bf5574";
    public static final String TEAM13 = RELEASE1 + "/Teameee388fcf45846d7b101fe7030b5ef6e";
    public static final String PHASE11 = RELEASE1 + "/Phase520d9bb734c8490cad6818f736da7a5e";
    public static final String TASK111 = PHASE11 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK1111 = TASK111 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK11111 = TASK1111 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK11112 = TASK1111 + "/Task97c27091a9b342599e1b631dc6d44727";
    public static final String TASK1112 = TASK111 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String COMMENT1111 = TASK111 + "/Comment9b27f1ead58f4dddbf4be92ae64944d3";
    public static final String TASK112 = PHASE11 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String TASK1121 = TASK112 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK113 = PHASE11 + "/Task31a0974f90b8450c98dbeef993f53667";
    public static final String TASK1131 = TASK113 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK1132 = TASK113 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String TASK114 = PHASE11 + "/Taskcecbc48333e04276b212a4091adf3928";
    public static final String TASK115 = PHASE11 + "/Task169e52908657406c9b5ae07a496c697c";
    public static final String TASK116 = PHASE11 + "/Task0cd42a56059b499ea216812e2afd5337";
    public static final String TASK1117 = TASK111 + "/Task0cd42a56059b499ea216812e2af3scnu";
    public static final String TASK1113 = TASK111 + "/Taskcecbc48333e04276b212a4091adf3928";
    public static final String TASK1114 = TASK111 + "/Task169e529086574063edrfe07a496c697c";
    public static final String TASK1115 = TASK111 + "/Task0cd42a56034f679ea216812e2afd5337";
    public static final String TASK1116 = TASK111 + "/Task0cd42a523sed499ea216812e2af897op";
    public static final String TASK1301 = TASK111 + "/Task0cd42a56059b499ea216812e2af3scnu";
    public static final String TASK1302 = PHASE11 + "/Task56c1a13b6121458db80462a2b9007589";
    public static final String TASK1303 = PHASE11 + "/Taskb258b91f239c4af5ad4983b805bef85b";
    public static final String TASK1304 = PHASE11 + "/Task01792025098140fd81b2d043b28b5556";
    public static final String TASK1305 = PHASE11 + "/Taskb2de7e22cbd34314a890e0603b20bd14";
    public static final String TASK1306 = PHASE11 + "/Task1b70084a288c4008a375430503e0064d";
    public static final String COMMENT1121 = TASK112 + "/Comment9b27f1ead58f4dddbf4be92ae64944d3";
    public static final String PHASE12 = RELEASE1 + "/Phase53228aef3564406aa3933efb0f6dfe26";
    public static final String TASK121 = PHASE12 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK122 = PHASE12 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String TASK123 = PHASE12 + "/Task63ae308b7b7f48f8a0774e1b8fa2cf62";
    public static final String PHASE13 = RELEASE1 + "/Phase37a01aaaeb954848bb9f4ca1d9bf786d";
    public static final String TASK131 = PHASE13 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String LINK01_ID = TASK111 + "/Link5240707dedfa4dbe84385844c8abcdc2";
    public static final String LINK02_ID = TASK111 + "/Linkb6bf576b72f84d4caddcb0e58a9f20c7";
    public static final String DEPENDENCY1111 = TASK111 + "/Dependency76ad0473a3a24ee1b961948db4532857";
    public static final String DEPENDENCY1112 = TASK111 + "/Dependencyfaef454f84c1420298962e6140a97cf6";
    public static final String DEPENDENCY11111 = TASK1111 + "/Dependency76ad0473a3a24ee1b961948db4532857";
    public static final String DEPENDENCY11112 = TASK1111 + "/Dependencyfaef454f84c1420298962e6140a97cf6";
    public static final String ATTACHMENT1 = RELEASE1 + "/Attachment313f941a22104133bd7008a605cdaa65";
    public static final String ATTACHMENT2 = RELEASE1 + "/Attachment0cea09a6415f405ca7dc37870bd8a24a";
    public static final String VARIABLE11 = RELEASE1 + "/Variable4d6814d312344aa68a36974e714bac0b";
    public static final String VARIABLE12 = RELEASE1 + "/Variableee19ea31563c4a5db7f0e2bd4571db72";
    public static final String VARIABLE13 = RELEASE1 + "/Variable843db033c69b41699d1e53d55d681d4f";
    public static final String VARIABLE14 = RELEASE1 + "/Variableb94df40571ad4caa96f5780dc34bcff5";
    public static final String VARIABLE15 = RELEASE1 + "/Variableba8c4de023934930be1a0e862fba5564";

    public static final String VARIABLE16 = "/Variable5be4358d7e7a4282b79e6cf474375978";

    public static final String RELEASE2 = RELEASES_DIR + "/Releasecaa6882c22ff46b89abf7140359df88a";
    public static final String PHASE21 = RELEASE2 + "/Phase520d9bb734c8490cad6818f736da7a5e";
    public static final String PHASE22 = RELEASE2 + "/Phase53228aef3564406aa3933efb0f6dfe26";
    public static final String TASK211 = PHASE21 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String DEPENDENCY2111 = TASK211 + "/Dependencyeb9d7c3d75654ea4ad9acbea99b0fa85";
    public static final String DEPENDENCY2112 = TASK211 + "/Dependencyfaef454f84c1420298962e6140a97cf6";
    public static final String TASK212 = PHASE21 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String VARIABLE21 = RELEASE2 + "/Variable4d6814d312344aa68a36974e714bac0b";
    public static final String TASK213 = PHASE21 + "/Task31a0974f90b8450c98dbeef993f53667";
    public static final String TASK214 = PHASE21 + "/Taske47e1bd870dc43048898ab82f235657c";
    public static final String TASK215 = PHASE21 + "/Taska2410814d3fc4916b5474a23c73a2fa7";

    public static final String RELEASE3 = RELEASES_DIR + "/Release9303b354aba041eea4e2486ed81f80c2";
    public static final String PHASE31 = RELEASE3 + "/Phase520d9bb734c8490cad6818f736da7a5e";
    public static final String TASK311 = PHASE31 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK3111 = TASK311 + "/Task2c4523ce33e94c18a09d3c089d42bbe7";
    public static final String TASK3112 = TASK311 + "/Taskd2b75135d42547ca8703a3a11261d931";
    public static final String TASK3113 = TASK311 + "/Taskc426c37a59864c17ba0324e7caeadb92";
    public static final String TASK312 = PHASE31 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String TASK313 = PHASE31 + "/Task499f2c4ba937453c9a18ea6ae43bd59b";
    public static final String TASK314 = PHASE31 + "/Task5ce9a5538b8e4c63a36bd985fd2cf270";

    public static final String RELEASE4 = RELEASES_DIR + "/Release4c0a37c875694c97b30fa971fc1ee03c";
    public static final String PHASE41 = RELEASE4 + "/Phasebdcfbf9122c55965fccc6c8e0e344531e1aceaf1";
    public static final String TASK411 = PHASE41 + "/Taskb32ba2b04b7417cf20e78749e08f6fd6416efb58";
    public static final String TASK412 = PHASE41 + "/Taskaf84d5f08654cf0679850b1622799fdb7bf433e1";

    public static final String RELEASE5 = RELEASES_DIR + "/Release18a1237a6df6409b941ab62a245141cc";
    public static final String PHASE51 = RELEASE5 + "/Phasebdcfbf9122c55965fccc6fdf0e344531e1aceaf1";
    public static final String TASK511 = PHASE51 + "/Taskb32ba2b04b743340e78749e08f6fd6416efb58";
    public static final String TASK512 = PHASE51 + "/Taskaf84d5f08654cf04322350b16227refdb7bf433e1";

    public static final String RELEASE6 = RELEASES_DIR + "/Released91ae6146f634506bd1a1d972c078eb3";
    public static final String PHASE61 = RELEASE6 + "/Phasebdcfbf955965fccc6c8e0e3445fddd31e1aceaf1";
    public static final String TASK611 = PHASE61 + "/Taskb32ba2b04fd17cf20e78749e08ftrd6416efb58";
    public static final String TASK612 = PHASE61 + "/Taskaf84d5f08654df0679850b1622799fdb7b5533e1";

    public static final String FOLDER7 = RELEASES_DIR + "/Folder01345a690c16b345168751d62934e912";
    public static final String RELEASE7 = FOLDER7 + "/Release1b029a856ad19280634adb209469816c";
    public static final String PHASE71 = RELEASE7 + "/Phase91c21374780d23dd1394447ed90bc56c";
    public static final String TASK71 = PHASE71 + "/Task5d63d4e78019ee2834620d2b05623560";
    public static final String RELEASE72 = FOLDER7 + "/Release1b029a856ad19280634adb209469817c";
    public static final String PHASE72 = RELEASE72 + "/Phase91c21374780d23dd1394447ed90bc57c";
    public static final String TASK72 = PHASE72 + "/Task5d63d4e78019ee2834620d2b05623570";
    public static final String VARIABLE71 = RELEASE7 + "/Variable4d6814d312344aa683dr5g4e714bac0b";
    public static final String VARIABLE72 = RELEASE7 + "/Variableee19ea31563c4345cgf0e2bd4571db72";

    public static final String FOLDER8 = RELEASES_DIR + "/Folder16471301a63401435604e56d1303c451";
    public static final String RELEASE8 = FOLDER8 + "/Releasef1f7abb37b9b4f18be37a3fe1c1ec294";
    public static final String PHASE81 = RELEASE8 + "/Phased459e54b2fc64fd7af818db98722fba7";
    public static final String TASK81 = PHASE81 + "/Task5f35e5a09ffc482c8d33bb0f56370ba9";
    public static final String TEAM81 = RELEASE8 + "/Teame170a6cc8399467990e818aef4bae5a8";
    public static final String FOLDER9 = FOLDER8 + "/Folder36471301a63401435604e56d1303c451";
    public static final String RELEASE9 = FOLDER9 + "/Release1b029a856ad19280634adb209469816d";
    public static final String PHASE91 = RELEASE9 + "/Phase920d9bb734c8490cad6818f736da7a5e";
    public static final String TASK91 = PHASE91 + "/Task99c27091a9b342599e1b631dc6d44726";

    public static final String FOLDER10 = "/Folder112ed5e207c04beda7e30747e7325675";
    public static final String RELEASE10 = FOLDER10 + "/Release54e4b44645244bdab4dcdc683ab98cd2";

    public static final String RELEASE11 = FOLDER10 + "/Releasec0792395255641d1b0c24c69dd544e4c";
    public static final String RELEASE12 = FOLDER10 + "/Release46c829c5d88b4d8eb51528e43d550900";
    public static final String RELEASE13 = FOLDER10 + "/Release8cba239e65034fa98e5a8378581f8b57";
    public static final String RELEASE14 = FOLDER10 + "/Release546eb0d67dc646758535e5422acc30c7";
    public static final String RELEASE15 = FOLDER10 + "/Release2413ff501506426ca9fcba35a64fd7c9";
    public static final String PHASE101 = RELEASE10 + "/Phase9363a2d786804632ab62fd3e1f8f0036";
    public static final String TASK101 = PHASE101 + "/Taska1338532fae74174b6aa004dec44d60c";
    public static final String TASK102 = PHASE101 + "/Taska7115c618a1e480ebd34a071b5a9d06f";
    public static final String TASK103 = PHASE101 + "/Task0f10fb08e01b4954bf402d8d6a38f4d8";
    public static final String TASK104 = PHASE101 + "/Task6896e21df2524abeab24fef7e4c37a34";
    public static final String TASK105 = PHASE101 + "/Task2071e75f54854fa3a52ed8b5df6f6aa6";

    public static final String TEAM91 = RELEASE9 + "/Teameacad5429e11459b879a2ec01cd4efc2";

    public static final String DELIVERY1 = "Delivery1f52dec93a394867925eedd0db9c0d45";

    public static final String STAGE11 = DELIVERY1 + "/Stageeb8e4671bbb649d182f52802493b608b";

    public static final String TRACKITEM11 = DELIVERY1 + "/TrackedItemd703a43bdcfb42a195541d82f96f39f5";

    public static final String STAGE1 = "Stage99c27091a9b342599e1b631dc6d44726";
    public static final String STAGE2 = "Stage920d9bb734c8490cad6818f736da7a5e";
    public static final String STAGE3 = "Stage36471301a63401435604e56d1303c451";

    public static final String TEMPLATE1 = RELEASES_DIR + "/ReleaseTemplate1a";
    public static final String TEMPLATE2 = RELEASES_DIR + "/ReleaseTemplate2a";
    public static final String TEMPLATE3 = FOLDER7 + "/ReleaseTemplate3foldered";
    public static final String TRIGGER_ID = "Triggera141c0a6e641454084ae761194ab6c3f";
    public static final String TRIGGER1 = RELEASES_DIR + "/" + TRIGGER_ID;
    public static final String TRIGGER2 = RELEASES_DIR + "/Trigger92eadf03ff2d4881850e7e3df75b3621";
    public static final String TRIGGER3 = RELEASES_DIR + "/Trigger10454ba2b4c400996ff8548e83771923";

    public static final String USER1 = ROOT + "John";

    public static final String RISK_PROFILE_PREFIX = "Configuration/riskProfiles";
    public static final String DEFAULT_RISK_PROFILE_ID = RISK_PROFILE_PREFIX + "/RiskProfileDefault";
    public static final String RISK_PROFILE1 = RISK_PROFILE_PREFIX + "/RiskProfilec10454ba2b4c400996ff8548e8377181";

    public static final String CONFIGURATION1 = CONFIGURATIONS_CUSTOM_PREFIX + "/Configuration5aa26e43e791309d574673c23c6978aa";

    public static final String ROLE1 = "Rolec4ca6d6a4a64466d97f2b0cd481c4d24";
    public static final String ROLE2 = "Rolee884ed48b83191cbf285b31469f22b34";
    public static final String ROLE3 = "Role00fb2c8e8530f960801782e64f51d513";
    public static final String ROLE4 = "Rolede43e888b904e830ac8084c49ba3ce6b";

    private TestIds() {
        throw new AssertionError();
    }
}

==> xlr-domain-test-utils-25.1.0-1216.113-sources.jar: com/xebialabs/xlrelease/TestIds.java <==
package com.xebialabs.xlrelease;

import static com.xebialabs.deployit.plugin.api.udm.Metadata.ConfigurationItemRoot.APPLICATIONS;
import static com.xebialabs.deployit.plugin.api.udm.Metadata.ConfigurationItemRoot.CONFIGURATION;

/**
 * Holds sets of ids to use in unit tests.
 * <p>
 * More and more business code depends on properly formed ids with coherent nesting. It's more convenient to define them once and for all here.
 * </p>
 */
public final class TestIds {
    private static final String ROOT = CONFIGURATION.getRootNodeName() + "/Users";
    public static final String RELEASES_DIR = APPLICATIONS.getRootNodeName();
    public static final String CONFIGURATIONS_CUSTOM_PREFIX = CONFIGURATION.getRootNodeName() + "/Custom";

    public static final String RELEASE1 = RELEASES_DIR + "/Release162151faba694d03aa3065665cf26f21";
    public static final String TEAM11 = RELEASE1 + "/Team175a73cb61dd42dfbaf6c0bf8190a99f";
    public static final String TEAM12 = RELEASE1 + "/Team96834368d2204b1e9dca9171e8bf5574";
    public static final String TEAM13 = RELEASE1 + "/Teameee388fcf45846d7b101fe7030b5ef6e";
    public static final String PHASE11 = RELEASE1 + "/Phase520d9bb734c8490cad6818f736da7a5e";
    public static final String TASK111 = PHASE11 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK1111 = TASK111 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK11111 = TASK1111 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK11112 = TASK1111 + "/Task97c27091a9b342599e1b631dc6d44727";
    public static final String TASK1112 = TASK111 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String COMMENT1111 = TASK111 + "/Comment9b27f1ead58f4dddbf4be92ae64944d3";
    public static final String TASK112 = PHASE11 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String TASK1121 = TASK112 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK113 = PHASE11 + "/Task31a0974f90b8450c98dbeef993f53667";
    public static final String TASK1131 = TASK113 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK1132 = TASK113 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String TASK114 = PHASE11 + "/Taskcecbc48333e04276b212a4091adf3928";
    public static final String TASK115 = PHASE11 + "/Task169e52908657406c9b5ae07a496c697c";
    public static final String TASK116 = PHASE11 + "/Task0cd42a56059b499ea216812e2afd5337";
    public static final String TASK117 = PHASE11 + "/Task56c1a13b6121458db80462a2b9007589";
    public static final String TASK1113 = TASK111 + "/Taskcecbc48333e04276b212a4091adf3928";
    public static final String TASK1114 = TASK111 + "/Task169e529086574063edrfe07a496c697c";
    public static final String TASK1115 = TASK111 + "/Task0cd42a56034f679ea216812e2afd5337";
    public static final String TASK1116 = TASK111 + "/Task0cd42a523sed499ea216812e2af897op";
    public static final String TASK1117 = TASK111 + "/Task0cd42a56059b499ea216812e2af3scnu";
    public static final String COMMENT1121 = TASK112 + "/Comment9b27f1ead58f4dddbf4be92ae64944d3";
    public static final String PHASE12 = RELEASE1 + "/Phase53228aef3564406aa3933efb0f6dfe26";
    public static final String TASK121 = PHASE12 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK122 = PHASE12 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String TASK123 = PHASE12 + "/Task63ae308b7b7f48f8a0774e1b8fa2cf62";
    public static final String PHASE13 = RELEASE1 + "/Phase37a01aaaeb954848bb9f4ca1d9bf786d";
    public static final String TASK131 = PHASE13 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String LINK01_ID = TASK111 + "/Link5240707dedfa4dbe84385844c8abcdc2";
    public static final String LINK02_ID = TASK111 + "/Linkb6bf576b72f84d4caddcb0e58a9f20c7";
    public static final String DEPENDENCY1111 = TASK111 + "/Dependency76ad0473a3a24ee1b961948db4532857";
    public static final String DEPENDENCY1112 = TASK111 + "/Dependencyfaef454f84c1420298962e6140a97cf6";
    public static final String DEPENDENCY11111 = TASK1111 + "/Dependency76ad0473a3a24ee1b961948db4532857";
    public static final String DEPENDENCY11112 = TASK1111 + "/Dependencyfaef454f84c1420298962e6140a97cf6";
    public static final String ATTACHMENT1 = RELEASE1 + "/Attachment313f941a22104133bd7008a605cdaa65";
    public static final String ATTACHMENT2 = RELEASE1 + "/Attachment0cea09a6415f405ca7dc37870bd8a24a";
    public static final String VARIABLE11 = RELEASE1 + "/Variable4d6814d312344aa68a36974e714bac0b";
    public static final String VARIABLE12 = RELEASE1 + "/Variableee19ea31563c4a5db7f0e2bd4571db72";
    public static final String VARIABLE13 = RELEASE1 + "/Variable843db033c69b41699d1e53d55d681d4f";
    public static final String VARIABLE14 = RELEASE1 + "/Variableb94df40571ad4caa96f5780dc34bcff5";
    public static final String VARIABLE15 = RELEASE1 + "/Variableba8c4de023934930be1a0e862fba5564";

    public static final String VARIABLE16 = "/Variable5be4358d7e7a4282b79e6cf474375978";

    public static final String RELEASE2 = RELEASES_DIR + "/Releasecaa6882c22ff46b89abf7140359df88a";
    public static final String TEAM21 = RELEASE2 + "/Team175a73cb61dd42dfbaf6c0bf8190a98f";
    public static final String PHASE21 = RELEASE2 + "/Phase520d9bb734c8490cad6818f736da7a5e";
    public static final String PHASE22 = RELEASE2 + "/Phase53228aef3564406aa3933efb0f6dfe26";
    public static final String TASK211 = PHASE21 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String DEPENDENCY2111 = TASK211 + "/Dependencyeb9d7c3d75654ea4ad9acbea99b0fa85";
    public static final String DEPENDENCY2112 = TASK211 + "/Dependencyfaef454f84c1420298962e6140a97cf6";
    public static final String TASK212 = PHASE21 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String VARIABLE21 = RELEASE2 + "/Variable4d6814d312344aa68a36974e714bac0b";
    public static final String TASK213 = PHASE21 + "/Task31a0974f90b8450c98dbeef993f53667";
    public static final String TASK214 = PHASE21 + "/Taske47e1bd870dc43048898ab82f235657c";
    public static final String TASK215 = PHASE21 + "/Taska2410814d3fc4916b5474a23c73a2fa7";

    public static final String RELEASE3 = RELEASES_DIR + "/Release9303b354aba041eea4e2486ed81f80c2";
    public static final String PHASE31 = RELEASE3 + "/Phase520d9bb734c8490cad6818f736da7a5e";
    public static final String TASK311 = PHASE31 + "/Task97c27091a9b342599e1b631dc6d44726";
    public static final String TASK3111 = TASK311 + "/Task2c4523ce33e94c18a09d3c089d42bbe7";
    public static final String TASK3112 = TASK311 + "/Taskd2b75135d42547ca8703a3a11261d931";
    public static final String TASK3113 = TASK311 + "/Taskc426c37a59864c17ba0324e7caeadb92";
    public static final String TASK312 = PHASE31 + "/Task5be4358d7e7a4282b79e6cf474375978";
    public static final String TASK313 = PHASE31 + "/Task499f2c4ba937453c9a18ea6ae43bd59b";
    public static final String TASK314 = PHASE31 + "/Task5ce9a5538b8e4c63a36bd985fd2cf270";

    public static final String RELEASE4 = RELEASES_DIR + "/Release4c0a37c875694c97b30fa971fc1ee03c";
    public static final String PHASE41 = RELEASE4 + "/Phasebdcfbf9122c55965fccc6c8e0e344531e1aceaf1";
    public static final String TASK411 = PHASE41 + "/Taskb32ba2b04b7417cf20e78749e08f6fd6416efb58";
    public static final String TASK412 = PHASE41 + "/Taskaf84d5f08654cf0679850b1622799fdb7bf433e1";

    public static final String RELEASE5 = RELEASES_DIR + "/Release18a1237a6df6409b941ab62a245141cc";
    public static final String PHASE51 = RELEASE5 + "/Phasebdcfbf9122c55965fccc6fdf0e344531e1aceaf1";
    public static final String TASK511 = PHASE51 + "/Taskb32ba2b04b743340e78749e08f6fd6416efb58";
    public static final String TASK512 = PHASE51 + "/Taskaf84d5f08654cf04322350b16227refdb7bf433e1";

    public static final String RELEASE6 = RELEASES_DIR + "/Released91ae6146f634506bd1a1d972c078eb3";
    public static final String PHASE61 = RELEASE6 + "/Phasebdcfbf955965fccc6c8e0e3445fddd31e1aceaf1";
    public static final String TASK611 = PHASE61 + "/Taskb32ba2b04fd17cf20e78749e08ftrd6416efb58";
    public static final String TASK612 = PHASE61 + "/Taskaf84d5f08654df0679850b1622799fdb7b5533e1";

    public static final String FOLDER7 = RELEASES_DIR + "/Folder01345a690c16b345168751d62934e912";
    public static final String RELEASE7 = FOLDER7 + "/Release1b029a856ad19280634adb209469816c";
    public static final String PHASE71 = RELEASE7 + "/Phase91c21374780d23dd1394447ed90bc56c";
    public static final String TASK71 = PHASE71 + "/Task5d63d4e78019ee2834620d2b05623560";
    public static final String RELEASE72 = FOLDER7 + "/Release1b029a856ad19280634adb209469817c";
    public static final String PHASE72 = RELEASE72 + "/Phase91c21374780d23dd1394447ed90bc57c";
    public static final String TASK72 = PHASE72 + "/Task5d63d4e78019ee2834620d2b05623570";
    public static final String VARIABLE71 = RELEASE7 + "/Variable4d6814d312344aa683dr5g4e714bac0b";
    public static final String VARIABLE72 = RELEASE7 + "/Variableee19ea31563c4345cgf0e2bd4571db72";

    public static final String FOLDER8 = RELEASES_DIR + "/Folder16471301a63401435604e56d1303c451";
    public static final String RELEASE8 = FOLDER8 + "/Releasef1f7abb37b9b4f18be37a3fe1c1ec294";
    public static final String PHASE81 = RELEASE8 + "/Phased459e54b2fc64fd7af818db98722fba7";
    public static final String TASK81 = PHASE81 + "/Task5f35e5a09ffc482c8d33bb0f56370ba9";
    public static final String TEAM81 = RELEASE8 + "/Teame170a6cc8399467990e818aef4bae5a8";
    public static final String FOLDER9 = FOLDER8 + "/Folder36471301a63401435604e56d1303c451";
    public static final String RELEASE9 = FOLDER9 + "/Release1b029a856ad19280634adb209469816d";
    public static final String PHASE91 = RELEASE9 + "/Phase920d9bb734c8490cad6818f736da7a5e";
    public static final String TASK91 = PHASE91 + "/Task99c27091a9b342599e1b631dc6d44726";

    public static final String FOLDER10 = "/Folder112ed5e207c04beda7e30747e7325675";
    public static final String RELEASE10 = FOLDER10 + "/Release54e4b44645244bdab4dcdc683ab98cd2";

    public static final String RELEASE11 = FOLDER10 + "/Releasec0792395255641d1b0c24c69dd544e4c";
    public static final String RELEASE12 = FOLDER10 + "/Release46c829c5d88b4d8eb51528e43d550900";
    public static final String RELEASE13 = FOLDER10 + "/Release8cba239e65034fa98e5a8378581f8b57";
    public static final String RELEASE14 = FOLDER10 + "/Release546eb0d67dc646758535e5422acc30c7";
    public static final String RELEASE15 = FOLDER10 + "/Release2413ff501506426ca9fcba35a64fd7c9";
    public static final String PHASE101 = RELEASE10 + "/Phase9363a2d786804632ab62fd3e1f8f0036";
    public static final String TASK101 = PHASE101 + "/Taska1338532fae74174b6aa004dec44d60c";
    public static final String TASK102 = PHASE101 + "/Taska7115c618a1e480ebd34a071b5a9d06f";
    public static final String TASK103 = PHASE101 + "/Task0f10fb08e01b4954bf402d8d6a38f4d8";
    public static final String TASK104 = PHASE101 + "/Task6896e21df2524abeab24fef7e4c37a34";
    public static final String TASK105 = PHASE101 + "/Task2071e75f54854fa3a52ed8b5df6f6aa6";

    public static final String TEAM91 = RELEASE9 + "/Teameacad5429e11459b879a2ec01cd4efc2";

    public static final String DELIVERY1 = "Delivery1f52dec93a394867925eedd0db9c0d45";

    public static final String STAGE11 = DELIVERY1 + "/Stageeb8e4671bbb649d182f52802493b608b";

    public static final String TRACKITEM11 = DELIVERY1 + "/TrackedItemd703a43bdcfb42a195541d82f96f39f5";

    public static final String STAGE1 = "Stage99c27091a9b342599e1b631dc6d44726";
    public static final String STAGE2 = "Stage920d9bb734c8490cad6818f736da7a5e";
    public static final String STAGE3 = "Stage36471301a63401435604e56d1303c451";

    public static final String TEMPLATE1 = RELEASES_DIR + "/ReleaseTemplate1a";
    public static final String TEMPLATE2 = RELEASES_DIR + "/ReleaseTemplate2a";
    public static final String TEMPLATE3 = FOLDER7 + "/ReleaseTemplate3foldered";
    public static final String TRIGGER_ID = "Triggera141c0a6e641454084ae761194ab6c3f";
    public static final String TRIGGER1 = RELEASES_DIR + "/" + TRIGGER_ID;
    public static final String TRIGGER2 = RELEASES_DIR + "/Trigger92eadf03ff2d4881850e7e3df75b3621";
    public static final String TRIGGER3 = RELEASES_DIR + "/Trigger10454ba2b4c400996ff8548e83771923";

    public static final String USER1 = ROOT + "John";

    public static final String RISK_PROFILE_PREFIX = "Configuration/riskProfiles";
    public static final String DEFAULT_RISK_PROFILE_ID = RISK_PROFILE_PREFIX + "/RiskProfileDefault";
    public static final String RISK_PROFILE1 = RISK_PROFILE_PREFIX + "/RiskProfilec10454ba2b4c400996ff8548e8377181";

    public static final String CONFIGURATION1 = CONFIGURATIONS_CUSTOM_PREFIX + "/Configuration5aa26e43e791309d574673c23c6978aa";

    public static final String ROLE1 = "Rolec4ca6d6a4a64466d97f2b0cd481c4d24";
    public static final String ROLE2 = "Rolee884ed48b83191cbf285b31469f22b34";
    public static final String ROLE3 = "Role00fb2c8e8530f960801782e64f51d513";
    public static final String ROLE4 = "Rolede43e888b904e830ac8084c49ba3ce6b";

    private TestIds() {
        throw new AssertionError();
    }
}
